---
title: 'Open Access: Background and Tools for Early Career Researchers in Social Sciences'
output:
  pdf_document: default
  html_document: default
bibliography: bibliography.bib
---

**Workshop outline**

---

**Philippe Joly**  
Humboldt-Universitt zu Berlin & WZB Berlin Social Science Center  
Email: jolyphil at hu-berlin.de

**Workshop prepared for: **  
Berlin Summer School in Social Sciences  
July 18, 2018 at 4 pm  

## Concept

This workshop aims at giving early career researchers in social sciences a basic knowledge of open access (OA) publishing and at introducing them to useful tools. We address questions such as: What are the limitations of the closed publication system? What is OA publishing? What are the different types of OA publications? What are the available licenses for OA publications? What is the share of OA publications in the scientific literature and how is this changing over time? What sort of funding is available for OA publishing? The workshop is structured around a 45 minute presentation punctuated by group discussions and exercises. 90 minutes are planned for the whole workshop. 

## Readings

In order to fully participate in the discussion, participants are encouraged to read the following text:

* [@mckiernan_point_2016]

## Bring your laptop!

Be sure to bring your laptop as we will try some online tools.

## Structure

### 1. What are the limitations of the closed publication system?

We start the workshop by discussing the limitations of the current subscription-based system. We explore publishers' current business model and examine its financial and ethical implications. Until recently, scholarly publication was funded almost exclusively through subscriptions. University libraries would strike "big deals" with publishers to get access to catalogs of journals for their users. While publishers could before be credited for formatting, printing, and distributing research papers, the actual value of this work has declined with the advent of digital communications. Nowadays, publishers act as gatekeepers, determining who has and who has not access to knowledge. A small number of publishers have established an oligopoly over high impact factor journals and the price of subscriptions has skyrocketed over the years. Publishers benefit from the free labor of authors and reviewers. 

### 2. What is open access publishing?

In this section, we introduce the concept of open access. While most researchers have an intuitive notion of what open access is, not everyone agrees on a precise definition. We discuss three types of OA publications: gold, hybrid, and green. While touching the subject of green OA, we explain the difference between pre and postprints.

*Small group discussion: Pros and cons (time: 15-20 minutes; material: large sheets of paper, post-its, and markers)*

* Participants join in small groups and discuss what are the advantages and disadvantages of different models of OA publishing: green, gold, and hybrid.
* We regroup in plenary to share our main conclusions. 

### 3. What is the share of open access publications in the scientific literature and what are their impact?

We look at the spread of OA over time in different disciplines and across different types of OA publications. We also discuss the impact of OA papers in terms of citations. The share of OA articles has increased dramatically over the years, but the development has been slower in sociology and political science. In general, articles in OA appear to be more cited, than articles placed behind a paywall.

### 4. Which license should you choose?

OA publications are usually available under a specific Creative Commons license. We discuss the different options: CC-0 and variants of CC-BY (-NC, -SA, -ND).

### 5. How to find funding for your open access publication?

Authors interested in publishing in gold or hybrid OA usually have to pay "Article Processing Charges" (APCs). We look at different funding options, including institutional publication funds.

### 6. Practical examples

In the last section of the workshop, we go over practical topics that could be of interest for all PhD candidates. 

#### Finding a self-archiving policy on SHERPA RoMEO

For people interested in publishing in green OA, we explore the [Sherpa/Romeo database](http://www.sherpa.ac.uk/romeo/index.php). 

#### Finding a gold OA journal on the Directory of Open Access Journals (DOAJ)

There are hundreds of OA journal in social sciences. How to make a choice and how to not fall into the trap of predatory OA journals? We look at the [Directory of Open Access Journals (DOAJ)](https://doaj.org/).

#### Looking for a preprint on SocArXiv

Preprints allow researchers to publish early research findings and make them available for free. We look at a new preprint repository in social sciences, [SocArXiv](https://socopen.org/), and explain how to link preprints with supplementary documentation, data, and code on the [Open Science Framework](https://osf.io/).

## Further reading

### General resources on open science

* [@open_science_mooc_notitle_2018]
* [@bezjak_open_2018]

### The limitations of the closed publication system

* [@buranyi_is_2017]
* [@lariviere_oligopoly_2015]
* [@schiermeier_scientists_2017]

### Open access: definitions

* [@bourne_ten_2017]
* [@budapest_open_access_initiative_boai15_2017]
* [@fund_guest_2018]

### Licenses

* [@klimpel_freies_2012]
* [@kreutzer_open_2014]
* [@redhead_why_2012]

### Diffusion and impact of OA publications

* [@bjork_open_2016]
* [@martin-martin_evidence_2018]
* [@piwowar_state_2018]
* [@tennant_academic_2016]

## Reuse of the material

The contents of the workshop are under a [CC BY 4.0 license](https://creativecommons.org/licenses/by/4.0/).

All the material of this workshop (including this outline, the slides, and the bibliography) can be cloned or downloaded from GitHub:  
https://github.com/jolyphil/oa-workshop 

## Acknowledgements

This workshop was prepared as part of the [Freies Wissen Fellowship](https://wikimedia.de/wiki/BildungWissenschaftKultur/Fellowprogramm) sponsored by Wikimedia Deutschland, the Stifterverband, and the VolkswagenStiftung.

This outline largely benefited from the webinar on open access presented by Christina Riesenweber (FU-CeDiS) and Agnieszka Wenninger (FU-CeDiS) on January 31, 2018, as part of the Freies Wissen Fellowship. Part of the references were found on the [Open Science MOOC](https://opensciencemooc.eu/). Alessandro Blasetti (WZB) provided useful resources on OA licenses.

## References